# Changelog

All notable changes to `cydrogen` will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## v0.0.5 - 2025-06-06

### Added

- Expose `pad` and `unpad` functions ([#32](https://github.com/stephane-martin/cydrogen/issues/32)).

## v0.0.4 - 2025-06-04

### Added

- Initial release published on [PyPI](https://pypi.org/project/cydrogen/).

